/***************************************************************************//**
 *   @file   AD799x.c
 *   @brief  Implementation of AD799x Driver.
 *   @author Dan Nechita
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 684
*******************************************************************************/

/******************************************************************************/
/***************************** Include Files **********************************/
/******************************************************************************/
#include "AD799x.h"		

/******************************************************************************/
/************************ Functions Definitions *******************************/
/******************************************************************************/

/***************************************************************************//**
 * @brief Initializes I2C.
 *
 * @return 1.
*******************************************************************************/
unsigned char AD799x_Init(void)
{
    I2C_Init(100000);
    
    return(1);
}

/***************************************************************************//**
 * @brief Writes data into the Configuration Register.
 *
 * @param registerValue - Data value to write.
 *
 * @return None.
*******************************************************************************/
void AD799x_SetRegisterValue(unsigned char registerValue)
{
    unsigned char data = 0;

    data = registerValue;
    I2C_Write( AD799X_ADDRESS, &data, 1, 1);
}

/***************************************************************************//**
 * @brief Reads the High byte and the Low byte of the conversion.
 *
 * @param convValue - It is used to store the conversion value. 
 * @param channel - Stores the channel number for the current conversion.
 * @param bitsNumber - Number of bits for the ADC data
 * @param channelsNo - Number of ADC channels
 *
 * @return none.
*******************************************************************************/
void AD799x_GetConversionResult(unsigned short* convValue,
                                unsigned char* channel,
				unsigned char bitsNumber,
                                unsigned char channelsNo)
{
    unsigned char data[2] = {0,0};
    
    I2C_Read(AD799X_ADDRESS, data, 2, 1);
    
    switch(channelsNo)
    {
    case 2:
        *channel = (data[0] & 0x10) >> 4;
        break;
    case 4:
        *channel = (data[0] & 0x30) >> 4;
        break;
    case 8:
        *channel = (data[0] & 0x70) >> 4;
        break;
    default:
        *channel = -1;
        break;
    }

    switch(bitsNumber)
    {
    case 8:
        *convValue = data[1];
        break;
    case 10:
        *convValue = ((data[0] & 0x03) << 8) + data[1];
        break;
    case 12:
        *convValue = ((data[0] & 0x0F) << 8) + data[1];
        break;
    default: 
        *convValue = -1;
        break;
    }
}
